16.8. cdist-type__apt_pin(7) — cdist 6.9.8 documentation

# 16.8. cdist-type__apt_pin(7)

## 16.8.1. NAME

cdist-type__apt_pin - Manage apt pinning rules

## 16.8.2. DESCRIPTION

Adds/removes/edits rules to pin some packages to a specific distribution. Useful if using multiple debian repositories at the same time. (Useful, if one wants to use a few specific packages from backports or perhaps Debain testing... or even sid.)

## 16.8.3. REQUIRED PARAMETERS

distribution

  Specifies what distribution the package should be pinned to. Accepts both codenames (buster/bullseye/sid) and suite names (stable/testing/...).

## 16.8.4. OPTIONAL PARAMETERS

package

  Package name, glob or regular expression to match (multiple) packages. If not specified __object_id is used.

priority

  The priority value to assign to matching packages. Deafults to 500. (To match the default target distro's priority)

state

  Will be passed to underlying __file type; see there for valid values and defaults.

## 16.8.5. BOOLEAN PARAMETERS

None.

## 16.8.6. EXAMPLES

    # Add the bullseye repo to buster, but do not install any packages by default,
    # only if explicitely asked for (-1 means "never" for apt)
     __apt_pin bullseye-default \
        --package "*" \
        --distribution bullseye \
        --priority -1

     require="__apt_pin/bullseye-default" __apt_source bullseye \
        --uri http://deb.debian.org/debian/ \
        --distribution bullseye \
        --component main

     __apt_pin foo --package "foo foo-*" --distribution bullseye

     __foo # Assuming, this installs the `foo` package internally

     __package foo-plugin-extras # Assuming we also need some extra stuff

## 16.8.7. SEE ALSO

apt_preferences(5) cdist-type__apt_source(7) cdist-type__apt_backports(7) cdist-type__file(7)

## 16.8.8. AUTHORS

Daniel Fancsali <fancsali@gmail.com>

## 16.8.9. COPYING

Copyright (C) 2021 Daniel Fancsali. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.